@@ -2,10 +2,17 @@
 // Implementation of base text editor class for FLTK.
 //
 
-#include <FL/Fl_Editor.H>
-#include <FL/fl_ask.H>
-#include <FL/Fl_Group.H>
-#include <FL/fl_draw.H>
+#if FL_MAJOR_VERSION == 1
+#	include <FL/Fl_Editor.H>
+#	include <FL/fl_ask.H>
+#	include <FL/Fl_Group.H>
+#	include <FL/fl_draw.H>
+#else
+#	include <fltk/Fl_Editor.h>
+#	include <fltk/fl_ask.h>
+#	include <fltk/Fl_Group.h>
+#	include <fltk/fl_draw.h>
+#endif
 
 // ugly workaround for drawing bug with FLTK 2.0 CVS													
 #if (FL_MAJOR_VERSION > 1)							
