@@ -1,6 +1,12 @@
-#include <FL/editvars.h>
-#include <FL/wstring.h>
-#include <FL/editengine.h>
+#if FL_MAJOR_VERSION == 1
+#	include <fltk/editvars.h>
+#	include <fltk/wstring.h>
+#	include <fltk/editengine.h>
+#else
+#	include <FL/editvars.h>
+#	include <FL/wstring.h>
+#	include <FL/editengine.h>
+#endif
 
 rclError EditorEngine::AppendClip()
 {
@@ -618,6 +624,8 @@ rclError EditorEngine::SaveTo(FILE *outfile)
 
 rclError EditorEngine::LoadFrom(const char *buffer)
 {
+	if(!(buffer && *buffer))
+		return NOERROR;		// can't do anything with null or empty buffer
 	LastResult = NOERROR;
 	bool reallychanged = FALSE;		// if empty, don't mark as changed
 	bool aslast = FALSE;
@@ -677,13 +685,15 @@ rclError EditorEngine::LoadFrom(const char *buffer)
 
 rclError EditorEngine::SaveTo(char *buffer)
 {
+	if(!buffer)
+		return NOMEMORY;
 	long row;
 	char softbuffer[10];
 	LastResult = NOERROR;
 
+	buffer[0] = '\0';
 	if (CharCount && buffer)	 // if nothing in it, don't write anything...
 	{
-		buffer[0] = '\0';
 		sprintf(softbuffer,"%c",SOFT_RETURN);
 		wString softreturn(softbuffer);
 		wString s;
